List of Examples
================

Sending and Receiving Multiple Types
------------------------------------

.. _ex-send-multypes:

.. literalinclude:: ../../examples/ex-LowLevel/ex-send-multypes.py
   :linenos:

Sending and Receiving Large Datasets
------------------------------------

.. _ex-send-recv:

.. literalinclude:: ../../examples/ex-LowLevel/ex-send-recv.py
   :linenos:

FODO Cell Example
-----------------

.. _ex-fodo:

.. literalinclude:: ../../examples/ex-fodo/ex-fodos.py
   :linenos:


PS Twiss Example
----------------

.. _ex-ps-twiss:

.. literalinclude:: ../../examples/ex-ps-twiss/ps-twiss.py
   :linenos:


LHC Example
-----------

.. _ex-lhc:

.. literalinclude:: ../../examples/ex-lhc-couplingLocal/lhc-couplingLocal.py
   :linenos:

Managing References Example
---------------------------

.. _ex-managing-refs:

.. literalinclude:: ../../examples/ex-managing-refs/ex-managing-refs.py
   :linenos:

Receiving Data from the LHC Example
-----------------------------------

.. _ex-recv-lhc:

.. literalinclude:: ../../examples/ex-recv-lhc/ex-defexpr.py
   :linenos: